import { Directive, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NG_VALIDATORS } from '@angular/forms';

/**
 * @abstract
 */
class ComparisonDirective {
    /**
     * @param {?} key
     */
    constructor(key) {
        this.key = key;
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validate(control) {
        this.ctrl = control;
        return !this.validateCore(control) ? this.createErrorObject() : null;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (this.ctrl) {
            this.ctrl.updateValueAndValidity();
        }
    }
    /**
     * @return {?}
     */
    createErrorObject() {
        const /** @type {?} */ error = {};
        error[this.key] = true;
        return error;
    }
    /**
     * @abstract
     * @param {?} control
     * @return {?}
     */
    validateCore(control) { }
}

class EqualToDirective extends ComparisonDirective {
    constructor() {
        super('ngEqualTo');
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validateCore(control) {
        return control.value === this.ngEqualTo;
    }
}
EqualToDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngEqualTo]',
                providers: [
                    {
                        provide: NG_VALIDATORS,
                        useExisting: EqualToDirective,
                        multi: true
                    }
                ]
            },] },
];
/**
 * @nocollapse
 */
EqualToDirective.ctorParameters = () => [];
EqualToDirective.propDecorators = {
    'ngEqualTo': [{ type: Input },],
};

class GreaterThanOrEqualToDirective extends ComparisonDirective {
    constructor() {
        super('ngGreaterThanOrEqualTo');
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validateCore(control) {
        return control.value >= this.ngGreaterThanOrEqualTo;
    }
}
GreaterThanOrEqualToDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngGreaterThanOrEqualTo]',
                providers: [
                    {
                        provide: NG_VALIDATORS,
                        useExisting: GreaterThanOrEqualToDirective,
                        multi: true
                    }
                ]
            },] },
];
/**
 * @nocollapse
 */
GreaterThanOrEqualToDirective.ctorParameters = () => [];
GreaterThanOrEqualToDirective.propDecorators = {
    'ngGreaterThanOrEqualTo': [{ type: Input },],
};

class GreaterThanDirective extends ComparisonDirective {
    constructor() {
        super('ngGreaterThan');
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validateCore(control) {
        return control.value > this.ngGreaterThan;
    }
}
GreaterThanDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngGreaterThan]',
                providers: [
                    {
                        provide: NG_VALIDATORS,
                        useExisting: GreaterThanDirective,
                        multi: true
                    }
                ]
            },] },
];
/**
 * @nocollapse
 */
GreaterThanDirective.ctorParameters = () => [];
GreaterThanDirective.propDecorators = {
    'ngGreaterThan': [{ type: Input },],
};

class LowerThanOrEqualDirective extends ComparisonDirective {
    constructor() {
        super('ngLowerThanOrEqual');
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validateCore(control) {
        return control.value <= this.ngLowerThanOrEqual;
    }
}
LowerThanOrEqualDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngLowerThanOrEqual]',
                providers: [
                    {
                        provide: NG_VALIDATORS,
                        useExisting: LowerThanOrEqualDirective,
                        multi: true
                    }
                ]
            },] },
];
/**
 * @nocollapse
 */
LowerThanOrEqualDirective.ctorParameters = () => [];
LowerThanOrEqualDirective.propDecorators = {
    'ngLowerThanOrEqual': [{ type: Input },],
};

class LowerThanDirective extends ComparisonDirective {
    constructor() {
        super('ngLowerThan');
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validateCore(control) {
        return control.value < this.ngLowerThan;
    }
}
LowerThanDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngLowerThan]',
                providers: [
                    {
                        provide: NG_VALIDATORS,
                        useExisting: LowerThanDirective,
                        multi: true
                    }
                ]
            },] },
];
/**
 * @nocollapse
 */
LowerThanDirective.ctorParameters = () => [];
LowerThanDirective.propDecorators = {
    'ngLowerThan': [{ type: Input },],
};

class NotEqualToDirective extends ComparisonDirective {
    constructor() {
        super('ngNotEqualTo');
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validateCore(control) {
        return control.value !== this.ngNotEqualTo;
    }
}
NotEqualToDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngNotEqualTo]',
                providers: [
                    {
                        provide: NG_VALIDATORS,
                        useExisting: NotEqualToDirective,
                        multi: true
                    }
                ]
            },] },
];
/**
 * @nocollapse
 */
NotEqualToDirective.ctorParameters = () => [];
NotEqualToDirective.propDecorators = {
    'ngNotEqualTo': [{ type: Input },],
};

class AngularComparisonModule {
}
AngularComparisonModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    EqualToDirective,
                    GreaterThanDirective,
                    GreaterThanOrEqualToDirective,
                    LowerThanOrEqualDirective,
                    LowerThanDirective,
                    NotEqualToDirective
                ],
                exports: [
                    EqualToDirective,
                    GreaterThanOrEqualToDirective,
                    GreaterThanDirective,
                    LowerThanOrEqualDirective,
                    LowerThanDirective,
                    NotEqualToDirective
                ]
            },] },
];
/**
 * @nocollapse
 */
AngularComparisonModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { AngularComparisonModule, ComparisonDirective as ɵb, EqualToDirective as ɵa, GreaterThanOrEqualToDirective as ɵd, GreaterThanDirective as ɵc, LowerThanOrEqualDirective as ɵe, LowerThanDirective as ɵf, NotEqualToDirective as ɵg };
//# sourceMappingURL=angular-comparison.js.map
